@@ -5,6 +5,7 @@ from ..models import Gallery
 from .factories import (
     GalleryFactory,
     GalleryCategoryFactory,
+    GalleryImageExtensionFactory,
     GalleryPluginFactory,
 )
 
@@ -25,6 +26,16 @@ class GalleryTestCase(TestCase):
             'Should return an empty image list.'))
 
 
+class GalleryImageExtensionTestCase(TestCase):
+    """Tests for the ``GalleryImageExtension`` model class."""
+    longMessage = True
+
+    def test_instantiation(self):
+        obj = GalleryImageExtensionFactory()
+        self.assertTrue(obj, msg=(
+            'Should be able to instantiate and save the object.'))
+
+
 class GalleryCategoryTestCase(TestCase):
     """Tests for the ``GalleryCategory`` model class."""
     longMessage = True
